| Portability | portable |
|---|---|
| Stability | experimental |
| Maintainer | dastapov@gmail.com |
Network.XMPP.MD5
Description
Takes the MD5 module supplied by Ian Lynagh and strips it a bit to reduce number of imports See http://web.comlab.ox.ac.uk/oucl/work/ian.lynagh/ and http://www.ietf.org/rfc/rfc1321.txt.